@@ -1,20 +1,18 @@
-/*
- * Copyright (C) 2009-2016 Joel Rosdahl
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
+// Copyright (C) 2009-2016 Joel Rosdahl
+//
+// This program is free software; you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option)
+// any later version.
+//
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+// more details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program; if not, write to the Free Software Foundation, Inc., 51
+// Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "ccache.h"
 #include "hashtable_itr.h"
@@ -24,47 +22,45 @@
 
 #include <zlib.h>
 
-/*
- * Sketchy specification of the manifest disk format:
- *
- * <magic>         magic number                        (4 bytes)
- * <version>       file format version                 (1 byte unsigned int)
- * <hash_size>     size of the hash fields (in bytes)  (1 byte unsigned int)
- * <reserved>      reserved for future use             (2 bytes)
- * ----------------------------------------------------------------------------
- * <n>             number of include file paths        (4 bytes unsigned int)
- * <path_0>        path to include file                (NUL-terminated string,
- * ...                                                  at most 1024 bytes)
- * <path_n-1>
- * ----------------------------------------------------------------------------
- * <n>             number of include file hash entries (4 bytes unsigned int)
- * <index[0]>      index of include file path          (4 bytes unsigned int)
- * <hash[0]>       hash of include file                (<hash_size> bytes)
- * <size[0]>       size of include file                (4 bytes unsigned int)
- * <mtime[0]>      mtime of include file               (8 bytes signed int)
- * <ctime[0]>      ctime of include file               (8 bytes signed int)
- * ...
- * <index[n-1]>
- * <hash[n-1]>
- * <size[n-1]>
- * <mtime[n-1]>
- * <ctime[n-1]>
- * ----------------------------------------------------------------------------
- * <n>             number of object name entries       (4 bytes unsigned int)
- * <m[0]>          number of include file hash indexes (4 bytes unsigned int)
- * <index[0][0]>   include file hash index             (4 bytes unsigned int)
- * ...
- * <index[0][m[0]-1]>
- * <hash[0]>       hash part of object name            (<hash_size> bytes)
- * <size[0]>       size part of object name            (4 bytes unsigned int)
- * ...
- * <m[n-1]>        number of include file hash indexes
- * <index[n-1][0]> include file hash index
- * ...
- * <index[n-1][m[n-1]]>
- * <hash[n-1]>
- * <size[n-1]>
- */
+// Sketchy specification of the manifest disk format:
+//
+// <magic>         magic number                        (4 bytes)
+// <version>       file format version                 (1 byte unsigned int)
+// <hash_size>     size of the hash fields (in bytes)  (1 byte unsigned int)
+// <reserved>      reserved for future use             (2 bytes)
+// ----------------------------------------------------------------------------
+// <n>             number of include file paths        (4 bytes unsigned int)
+// <path_0>        path to include file                (NUL-terminated string,
+// ...                                                  at most 1024 bytes)
+// <path_n-1>
+// ----------------------------------------------------------------------------
+// <n>             number of include file hash entries (4 bytes unsigned int)
+// <index[0]>      index of include file path          (4 bytes unsigned int)
+// <hash[0]>       hash of include file                (<hash_size> bytes)
+// <size[0]>       size of include file                (4 bytes unsigned int)
+// <mtime[0]>      mtime of include file               (8 bytes signed int)
+// <ctime[0]>      ctime of include file               (8 bytes signed int)
+// ...
+// <index[n-1]>
+// <hash[n-1]>
+// <size[n-1]>
+// <mtime[n-1]>
+// <ctime[n-1]>
+// ----------------------------------------------------------------------------
+// <n>             number of object name entries       (4 bytes unsigned int)
+// <m[0]>          number of include file hash indexes (4 bytes unsigned int)
+// <index[0][0]>   include file hash index             (4 bytes unsigned int)
+// ...
+// <index[0][m[0]-1]>
+// <hash[0]>       hash part of object name            (<hash_size> bytes)
+// <size[0]>       size part of object name            (4 bytes unsigned int)
+// ...
+// <m[n-1]>        number of include file hash indexes
+// <index[n-1][0]> include file hash index
+// ...
+// <index[n-1][m[n-1]]>
+// <hash[n-1]>
+// <size[n-1]>
 
 static const uint32_t MAGIC = 0x63436d46U;
 static const uint32_t MAX_MANIFEST_ENTRIES = 100;
@@ -74,46 +70,46 @@ static const uint32_t MAX_MANIFEST_FILE_INFO_ENTRIES = 10000;
   do { enum { ccache_static_assert__ = 1/(e) }; } while (false)
 
 struct file_info {
-	/* Index to n_files. */
+	// Index to n_files.
 	uint32_t index;
-	/* Hash of referenced file. */
+	// Hash of referenced file.
 	uint8_t hash[16];
-	/* Size of referenced file. */
+	// Size of referenced file.
 	uint32_t size;
-	/* mtime of referenced file. */
+	// mtime of referenced file.
 	int64_t mtime;
-	/* ctime of referenced file. */
+	// ctime of referenced file.
 	int64_t ctime;
 };
 
 struct object {
-	/* Number of entries in file_info_indexes. */
+	// Number of entries in file_info_indexes.
 	uint32_t n_file_info_indexes;
-	/* Indexes to file_infos. */
+	// Indexes to file_infos.
 	uint32_t *file_info_indexes;
-	/* Hash of the object itself. */
+	// Hash of the object itself.
 	struct file_hash hash;
 };
 
 struct manifest {
-	/* Version of decoded file. */
+	// Version of decoded file.
 	uint8_t version;
 
-	/* Reserved for future use. */
+	// Reserved for future use.
 	uint16_t reserved;
 
-	/* Size of hash fields (in bytes). */
+	// Size of hash fields (in bytes).
 	uint8_t hash_size;
 
-	/* Referenced include files. */
+	// Referenced include files.
 	uint32_t n_files;
 	char **files;
 
-	/* Information about referenced include files. */
+	// Information about referenced include files.
 	uint32_t n_file_infos;
 	struct file_info *file_infos;
 
-	/* Object names plus references to include file hashes. */
+	// Object names plus references to include file hashes.
 	uint32_t n_objects;
 	struct object *objects;
 };
@@ -127,7 +123,7 @@ struct file_stats {
 static unsigned int
 hash_from_file_info(void *key)
 {
-	ccache_static_assert(sizeof(struct file_info) == 40); /* No padding. */
+	ccache_static_assert(sizeof(struct file_info) == 40); // No padding.
 	return murmurhashneutral2(key, sizeof(struct file_info), 0);
 }
 
@@ -146,13 +142,12 @@ file_infos_equal(void *key1, void *key2)
 static void
 free_manifest(struct manifest *mf)
 {
-	uint32_t i;
-	for (i = 0; i < mf->n_files; i++) {
+	for (uint32_t i = 0; i < mf->n_files; i++) {
 		free(mf->files[i]);
 	}
 	free(mf->files);
 	free(mf->file_infos);
-	for (i = 0; i < mf->n_objects; i++) {
+	for (uint32_t i = 0; i < mf->n_objects; i++) {
 		free(mf->objects[i].file_info_indexes);
 	}
 	free(mf->objects);
@@ -161,8 +156,7 @@ free_manifest(struct manifest *mf)
 
 #define READ_BYTE(var) \
   do { \
-		int ch_; \
-		ch_ = gzgetc(f); \
+		int ch_ = gzgetc(f); \
 		if (ch_ == EOF) { \
 			goto error; \
 		} \
@@ -171,11 +165,9 @@ free_manifest(struct manifest *mf)
 
 #define READ_INT(size, var) \
   do { \
-		int ch_; \
-		size_t i_; \
 		(var) = 0; \
-		for (i_ = 0; i_ < (size); i_++) { \
-			ch_ = gzgetc(f); \
+		for (size_t i_ = 0; i_ < (size); i_++) { \
+			int ch_ = gzgetc(f); \
 			if (ch_ == EOF) { \
 				goto error; \
 			} \
@@ -188,9 +180,8 @@ free_manifest(struct manifest *mf)
   do { \
 		char buf_[1024]; \
 		size_t i_; \
-		int ch_; \
 		for (i_ = 0; i_ < sizeof(buf_); i_++) { \
-			ch_ = gzgetc(f); \
+			int ch_ = gzgetc(f); \
 			if (ch_ == EOF) { \
 				goto error; \
 			} \
@@ -207,10 +198,8 @@ free_manifest(struct manifest *mf)
 
 #define READ_BYTES(n, var) \
   do { \
-		size_t i_; \
-		int ch_; \
-		for (i_ = 0; i_ < (n); i_++) { \
-			ch_ = gzgetc(f); \
+		for (size_t i_ = 0; i_ < (n); i_++) { \
+			int ch_ = gzgetc(f); \
 			if (ch_ == EOF) { \
 				goto error; \
 			} \
@@ -221,9 +210,7 @@ free_manifest(struct manifest *mf)
 static struct manifest *
 create_empty_manifest(void)
 {
-	struct manifest *mf;
-
-	mf = x_malloc(sizeof(*mf));
+	struct manifest *mf = x_malloc(sizeof(*mf));
 	mf->hash_size = 16;
 	mf->n_files = 0;
 	mf->files = NULL;
@@ -238,44 +225,39 @@ create_empty_manifest(void)
 static struct manifest *
 read_manifest(gzFile f)
 {
-	struct manifest *mf;
-	uint32_t i, j;
+	struct manifest *mf = create_empty_manifest();
+
 	uint32_t magic;
-
-	mf = create_empty_manifest();
-
 	READ_INT(4, magic);
 	if (magic != MAGIC) {
 		cc_log("Manifest file has bad magic number %u", magic);
-		free_manifest(mf);
-		return NULL;
+		goto error;
 	}
+
 	READ_BYTE(mf->version);
 	if (mf->version != MANIFEST_VERSION) {
 		cc_log("Manifest file has unknown version %u", mf->version);
-		free_manifest(mf);
-		return NULL;
+		goto error;
 	}
 
 	READ_BYTE(mf->hash_size);
 	if (mf->hash_size != 16) {
-		/* Temporary measure until we support different hash algorithms. */
+		// Temporary measure until we support different hash algorithms.
 		cc_log("Manifest file has unsupported hash size %u", mf->hash_size);
-		free_manifest(mf);
-		return NULL;
+		goto error;
 	}
 
 	READ_INT(2, mf->reserved);
 
 	READ_INT(4, mf->n_files);
 	mf->files = x_calloc(mf->n_files, sizeof(*mf->files));
-	for (i = 0; i < mf->n_files; i++) {
+	for (uint32_t i = 0; i < mf->n_files; i++) {
 		READ_STR(mf->files[i]);
 	}
 
 	READ_INT(4, mf->n_file_infos);
 	mf->file_infos = x_calloc(mf->n_file_infos, sizeof(*mf->file_infos));
-	for (i = 0; i < mf->n_file_infos; i++) {
+	for (uint32_t i = 0; i < mf->n_file_infos; i++) {
 		READ_INT(4, mf->file_infos[i].index);
 		READ_BYTES(mf->hash_size, mf->file_infos[i].hash);
 		READ_INT(4, mf->file_infos[i].size);
@@ -285,12 +267,12 @@ read_manifest(gzFile f)
 
 	READ_INT(4, mf->n_objects);
 	mf->objects = x_calloc(mf->n_objects, sizeof(*mf->objects));
-	for (i = 0; i < mf->n_objects; i++) {
+	for (uint32_t i = 0; i < mf->n_objects; i++) {
 		READ_INT(4, mf->objects[i].n_file_info_indexes);
 		mf->objects[i].file_info_indexes =
 		  x_calloc(mf->objects[i].n_file_info_indexes,
 		           sizeof(*mf->objects[i].file_info_indexes));
-		for (j = 0; j < mf->objects[i].n_file_info_indexes; j++) {
+		for (uint32_t j = 0; j < mf->objects[i].n_file_info_indexes; j++) {
 			READ_INT(4, mf->objects[i].file_info_indexes[j]);
 		}
 		READ_BYTES(mf->hash_size, mf->objects[i].hash.hash);
@@ -337,20 +319,18 @@ error:
 static int
 write_manifest(gzFile f, const struct manifest *mf)
 {
-	uint32_t i, j;
-
 	WRITE_INT(4, MAGIC);
 	WRITE_INT(1, MANIFEST_VERSION);
 	WRITE_INT(1, 16);
 	WRITE_INT(2, 0);
 
 	WRITE_INT(4, mf->n_files);
-	for (i = 0; i < mf->n_files; i++) {
+	for (uint32_t i = 0; i < mf->n_files; i++) {
 		WRITE_STR(mf->files[i]);
 	}
 
 	WRITE_INT(4, mf->n_file_infos);
-	for (i = 0; i < mf->n_file_infos; i++) {
+	for (uint32_t i = 0; i < mf->n_file_infos; i++) {
 		WRITE_INT(4, mf->file_infos[i].index);
 		WRITE_BYTES(mf->hash_size, mf->file_infos[i].hash);
 		WRITE_INT(4, mf->file_infos[i].size);
@@ -359,9 +339,9 @@ write_manifest(gzFile f, const struct manifest *mf)
 	}
 
 	WRITE_INT(4, mf->n_objects);
-	for (i = 0; i < mf->n_objects; i++) {
+	for (uint32_t i = 0; i < mf->n_objects; i++) {
 		WRITE_INT(4, mf->objects[i].n_file_info_indexes);
-		for (j = 0; j < mf->objects[i].n_file_info_indexes; j++) {
+		for (uint32_t j = 0; j < mf->objects[i].n_file_info_indexes; j++) {
 			WRITE_INT(4, mf->objects[i].file_info_indexes[j]);
 		}
 		WRITE_BYTES(mf->hash_size, mf->objects[i].hash.hash);
@@ -379,12 +359,7 @@ static int
 verify_object(struct conf *conf, struct manifest *mf, struct object *obj,
               struct hashtable *stated_files, struct hashtable *hashed_files)
 {
-	uint32_t i;
-	struct file_hash *actual;
-	struct mdfour hash;
-	int result;
-
-	for (i = 0; i < obj->n_file_info_indexes; i++) {
+	for (uint32_t i = 0; i < obj->n_file_info_indexes; i++) {
 		struct file_info *fi = &mf->file_infos[obj->file_info_indexes[i]];
 		char *path = mf->files[fi->index];
 		struct file_stats *st = hashtable_search(stated_files, path);
@@ -401,11 +376,9 @@ verify_object(struct conf *conf, struct manifest *mf, struct object *obj,
 		}
 
 		if (conf->sloppiness & SLOPPY_FILE_STAT_MATCHES) {
-			/*
-			 * st->ctime is sometimes 0, so we can't check that both st->ctime and
-			 * st->mtime are greater than time_of_compilation. But it's sufficient to
-			 * check that either is.
-			 */
+			// st->ctime is sometimes 0, so we can't check that both st->ctime and
+			// st->mtime are greater than time_of_compilation. But it's sufficient to
+			// check that either is.
 			if (fi->size == st->size
 			    && fi->mtime == st->mtime
 			    && fi->ctime == st->ctime
@@ -417,20 +390,19 @@ verify_object(struct conf *conf, struct manifest *mf, struct object *obj,
 			}
 		}
 
-		actual = hashtable_search(hashed_files, path);
+		struct file_hash *actual = hashtable_search(hashed_files, path);
 		if (!actual) {
-			actual = x_malloc(sizeof(*actual));
+			struct mdfour hash;
 			hash_start(&hash);
-			result = hash_source_code_file(conf, &hash, path);
+			int result = hash_source_code_file(conf, &hash, path);
 			if (result & HASH_SOURCE_CODE_ERROR) {
 				cc_log("Failed hashing %s", path);
-				free(actual);
 				return 0;
 			}
 			if (result & HASH_SOURCE_CODE_FOUND_TIME) {
-				free(actual);
 				return 0;
 			}
+			actual = x_malloc(sizeof(*actual));
 			hash_result_as_bytes(&hash, actual->hash);
 			actual->size = hash.totalN;
 			hashtable_insert(hashed_files, x_strdup(path), actual);
@@ -447,13 +419,10 @@ verify_object(struct conf *conf, struct manifest *mf, struct object *obj,
 static struct hashtable *
 create_string_index_map(char **strings, uint32_t len)
 {
-	uint32_t i;
-	struct hashtable *h;
-	uint32_t *index;
-
-	h = create_hashtable(1000, hash_from_string, strings_equal);
-	for (i = 0; i < len; i++) {
-		index = x_malloc(sizeof(*index));
+	struct hashtable *h =
+	  create_hashtable(1000, hash_from_string, strings_equal);
+	for (uint32_t i = 0; i < len; i++) {
+		uint32_t *index = x_malloc(sizeof(*index));
 		*index = i;
 		hashtable_insert(h, x_strdup(strings[i]), index);
 	}
@@ -463,16 +432,12 @@ create_string_index_map(char **strings, uint32_t len)
 static struct hashtable *
 create_file_info_index_map(struct file_info *infos, uint32_t len)
 {
-	uint32_t i;
-	struct hashtable *h;
-	struct file_info *fi;
-	uint32_t *index;
-
-	h = create_hashtable(1000, hash_from_file_info, file_infos_equal);
-	for (i = 0; i < len; i++) {
-		fi = x_malloc(sizeof(*fi));
+	struct hashtable *h =
+	  create_hashtable(1000, hash_from_file_info, file_infos_equal);
+	for (uint32_t i = 0; i < len; i++) {
+		struct file_info *fi = x_malloc(sizeof(*fi));
 		*fi = infos[i];
-		index = x_malloc(sizeof(*index));
+		uint32_t *index = x_malloc(sizeof(*index));
 		*index = i;
 		hashtable_insert(h, fi, index);
 	}
@@ -483,19 +448,15 @@ static uint32_t
 get_include_file_index(struct manifest *mf, char *path,
                        struct hashtable *mf_files)
 {
-	uint32_t *index;
-	uint32_t n;
-
-	index = hashtable_search(mf_files, path);
+	uint32_t *index = hashtable_search(mf_files, path);
 	if (index) {
 		return *index;
 	}
 
-	n = mf->n_files;
+	uint32_t n = mf->n_files;
 	mf->files = x_realloc(mf->files, (n + 1) * sizeof(*mf->files));
 	mf->n_files++;
 	mf->files[n] = x_strdup(path);
-
 	return n;
 }
 
@@ -507,23 +468,18 @@ get_file_hash_index(struct manifest *mf,
                     struct hashtable *mf_file_infos)
 {
 	struct file_info fi;
-	uint32_t *fi_index;
-	uint32_t n;
-	struct stat file_stat;
-
 	fi.index = get_include_file_index(mf, path, mf_files);
 	memcpy(fi.hash, file_hash->hash, sizeof(fi.hash));
 	fi.size = file_hash->size;
 
-	/*
-	 * file_stat.st_{m,c}time has a resolution of 1 second, so we can cache the
-	 * file's mtime and ctime only if they're at least one second older than
-	 * time_of_compilation.
-	 *
-	 * st->ctime may be 0, so we have to check time_of_compilation against
-	 * MAX(mtime, ctime).
-	 */
+	// file_stat.st_{m,c}time has a resolution of 1 second, so we can cache the
+	// file's mtime and ctime only if they're at least one second older than
+	// time_of_compilation.
+	//
+	// st->ctime may be 0, so we have to check time_of_compilation against
+	// MAX(mtime, ctime).
 
+	struct stat file_stat;
 	if (stat(path, &file_stat) != -1
 	    && time_of_compilation > MAX(file_stat.st_mtime, file_stat.st_ctime)) {
 		fi.mtime = file_stat.st_mtime;
@@ -533,16 +489,15 @@ get_file_hash_index(struct manifest *mf,
 		fi.ctime = -1;
 	}
 
-	fi_index = hashtable_search(mf_file_infos, &fi);
+	uint32_t *fi_index = hashtable_search(mf_file_infos, &fi);
 	if (fi_index) {
 		return *fi_index;
 	}
 
-	n = mf->n_file_infos;
+	uint32_t n = mf->n_file_infos;
 	mf->file_infos = x_realloc(mf->file_infos, (n + 1) * sizeof(*mf->file_infos));
 	mf->n_file_infos++;
 	mf->file_infos[n] = fi;
-
 	return n;
 }
 
@@ -550,19 +505,18 @@ static void
 add_file_info_indexes(uint32_t *indexes, uint32_t size,
                       struct manifest *mf, struct hashtable *included_files)
 {
-	struct hashtable_itr *iter;
-	uint32_t i;
-	struct hashtable *mf_files; /* path --> index */
-	struct hashtable *mf_file_infos; /* struct file_info --> index */
-
 	if (size == 0) {
 		return;
 	}
 
-	mf_files = create_string_index_map(mf->files, mf->n_files);
-	mf_file_infos = create_file_info_index_map(mf->file_infos, mf->n_file_infos);
-	iter = hashtable_iterator(included_files);
-	i = 0;
+	// path --> index
+	struct hashtable *mf_files =
+	  create_string_index_map(mf->files, mf->n_files);
+	// struct file_info --> index
+	struct hashtable *mf_file_infos =
+	  create_file_info_index_map(mf->file_infos, mf->n_file_infos);
+	struct hashtable_itr *iter = hashtable_iterator(included_files);
+	uint32_t i = 0;
 	do {
 		char *path = hashtable_iterator_key(iter);
 		struct file_hash *file_hash = hashtable_iterator_value(iter);
@@ -581,40 +535,33 @@ add_object_entry(struct manifest *mf,
                  struct file_hash *object_hash,
                  struct hashtable *included_files)
 {
-	struct object *obj;
-	uint32_t n;
-
-	n = mf->n_objects;
-	mf->objects = x_realloc(mf->objects, (n + 1) * sizeof(*mf->objects));
+	uint32_t n_objs = mf->n_objects;
+	mf->objects = x_realloc(mf->objects, (n_objs + 1) * sizeof(*mf->objects));
 	mf->n_objects++;
-	obj = &mf->objects[n];
+	struct object *obj = &mf->objects[n_objs];
 
-	n = hashtable_count(included_files);
-	obj->n_file_info_indexes = n;
-	obj->file_info_indexes = x_malloc(n * sizeof(*obj->file_info_indexes));
-	add_file_info_indexes(obj->file_info_indexes, n, mf, included_files);
+	uint32_t n_fii = hashtable_count(included_files);
+	obj->n_file_info_indexes = n_fii;
+	obj->file_info_indexes = x_malloc(n_fii * sizeof(*obj->file_info_indexes));
+	add_file_info_indexes(obj->file_info_indexes, n_fii, mf, included_files);
 	memcpy(obj->hash.hash, object_hash->hash, mf->hash_size);
 	obj->hash.size = object_hash->size;
 }
 
-/*
- * Try to get the object hash from a manifest file. Caller frees. Returns NULL
- * on failure.
- */
+// Try to get the object hash from a manifest file. Caller frees. Returns NULL
+// on failure.
 struct file_hash *
 manifest_get(struct conf *conf, const char *manifest_path)
 {
-	int fd;
 	gzFile f = NULL;
 	struct manifest *mf = NULL;
-	struct hashtable *hashed_files = NULL; /* path --> struct file_hash */
-	struct hashtable *stated_files = NULL; /* path --> struct file_stats */
-	uint32_t i;
+	struct hashtable *hashed_files = NULL; // path --> struct file_hash
+	struct hashtable *stated_files = NULL; // path --> struct file_stats
 	struct file_hash *fh = NULL;
 
-	fd = open(manifest_path, O_RDONLY | O_BINARY);
+	int fd = open(manifest_path, O_RDONLY | O_BINARY);
 	if (fd == -1) {
-		/* Cache miss. */
+		// Cache miss.
 		cc_log("No such manifest file");
 		goto out;
 	}
@@ -633,8 +580,8 @@ manifest_get(struct conf *conf, const char *manifest_path)
 	hashed_files = create_hashtable(1000, hash_from_string, strings_equal);
 	stated_files = create_hashtable(1000, hash_from_string, strings_equal);
 
-	/* Check newest object first since it's a bit more likely to match. */
-	for (i = mf->n_objects; i > 0; i--) {
+	// Check newest object first since it's a bit more likely to match.
+	for (uint32_t i = mf->n_objects; i > 0; i--) {
 		if (verify_object(conf, mf, &mf->objects[i - 1],
 		                  stated_files, hashed_files)) {
 			fh = x_malloc(sizeof(*fh));
@@ -659,30 +606,24 @@ out:
 	return fh;
 }
 
-/*
- * Put the object name into a manifest file given a set of included files.
- * Returns true on success, otherwise false.
- */
+// Put the object name into a manifest file given a set of included files.
+// Returns true on success, otherwise false.
 bool
 manifest_put(const char *manifest_path, struct file_hash *object_hash,
              struct hashtable *included_files)
 {
 	int ret = 0;
-	int fd1;
-	int fd2;
 	gzFile f2 = NULL;
 	struct manifest *mf = NULL;
 	char *tmp_file = NULL;
 
-	/*
-	 * We don't bother to acquire a lock when writing the manifest to disk. A
-	 * race between two processes will only result in one lost entry, which is
-	 * not a big deal, and it's also very unlikely.
-	 */
+	// We don't bother to acquire a lock when writing the manifest to disk. A
+	// race between two processes will only result in one lost entry, which is
+	// not a big deal, and it's also very unlikely.
 
-	fd1 = open(manifest_path, O_RDONLY | O_BINARY);
+	int fd1 = open(manifest_path, O_RDONLY | O_BINARY);
 	if (fd1 == -1) {
-		/* New file. */
+		// New file.
 		mf = create_empty_manifest();
 	} else {
 		gzFile f1 = gzdopen(fd1, "rb");
@@ -701,27 +642,24 @@ manifest_put(const char *manifest_path, struct file_hash *object_hash,
 	}
 
 	if (mf->n_objects > MAX_MANIFEST_ENTRIES) {
-		/*
-		 * Normally, there shouldn't be many object entries in the manifest since
-		 * new entries are added only if an include file has changed but not the
-		 * source file, and you typically change source files more often than
-		 * header files. However, it's certainly possible to imagine cases where
-		 * the manifest will grow large (for instance, a generated header file that
-		 * changes for every build), and this must be taken care of since
-		 * processing an ever growing manifest eventually will take too much time.
-		 * A good way of solving this would be to maintain the object entries in
-		 * LRU order and discarding the old ones. An easy way is to throw away all
-		 * entries when there are too many. Let's do that for now.
-		 */
+		// Normally, there shouldn't be many object entries in the manifest since
+		// new entries are added only if an include file has changed but not the
+		// source file, and you typically change source files more often than
+		// header files. However, it's certainly possible to imagine cases where
+		// the manifest will grow large (for instance, a generated header file that
+		// changes for every build), and this must be taken care of since
+		// processing an ever growing manifest eventually will take too much time.
+		// A good way of solving this would be to maintain the object entries in
+		// LRU order and discarding the old ones. An easy way is to throw away all
+		// entries when there are too many. Let's do that for now.
 		cc_log("More than %u entries in manifest file; discarding",
 		       MAX_MANIFEST_ENTRIES);
 		free_manifest(mf);
 		mf = create_empty_manifest();
 	} else if (mf->n_file_infos > MAX_MANIFEST_FILE_INFO_ENTRIES) {
-		/* Rarely, file_info entries can grow large in pathological cases where
-		 * many included files change, but the main file does not. This also puts
-		 * an upper bound on the number of file_info entries.
-		 */
+		// Rarely, file_info entries can grow large in pathological cases where
+		// many included files change, but the main file does not. This also puts
+		// an upper bound on the number of file_info entries.
 		cc_log("More than %u file_info entries in manifest file; discarding",
 		       MAX_MANIFEST_FILE_INFO_ENTRIES);
 		free_manifest(mf);
@@ -729,7 +667,7 @@ manifest_put(const char *manifest_path, struct file_hash *object_hash,
 	}
 
 	tmp_file = format("%s.tmp", manifest_path);
-	fd2 = create_tmp_fd(&tmp_file);
+	int fd2 = create_tmp_fd(&tmp_file);
 	f2 = gzdopen(fd2, "wb");
 	if (!f2) {
 		cc_log("Failed to gzdopen %s", tmp_file);
@@ -768,12 +706,10 @@ bool
 manifest_dump(const char *manifest_path, FILE *stream)
 {
 	struct manifest *mf = NULL;
-	int fd;
 	gzFile f = NULL;
 	bool ret = false;
-	unsigned i, j;
 
-	fd = open(manifest_path, O_RDONLY | O_BINARY);
+	int fd = open(manifest_path, O_RDONLY | O_BINARY);
 	if (fd == -1) {
 		fprintf(stderr, "No such manifest file: %s\n", manifest_path);
 		goto out;
@@ -799,11 +735,11 @@ manifest_dump(const char *manifest_path, FILE *stream)
 	fprintf(stream, "Hash size: %u\n", (unsigned)mf->hash_size);
 	fprintf(stream, "Reserved field: %u\n", (unsigned)mf->reserved);
 	fprintf(stream, "File paths (%u):\n", (unsigned)mf->n_files);
-	for (i = 0; i < mf->n_files; ++i) {
+	for (unsigned i = 0; i < mf->n_files; ++i) {
 		fprintf(stream, "  %u: %s\n", i, mf->files[i]);
 	}
 	fprintf(stream, "File infos (%u):\n", (unsigned)mf->n_file_infos);
-	for (i = 0; i < mf->n_file_infos; ++i) {
+	for (unsigned i = 0; i < mf->n_file_infos; ++i) {
 		char *hash;
 		fprintf(stream, "  %u:\n", i);
 		fprintf(stream, "    Path index: %u\n", mf->file_infos[i].index);
@@ -815,11 +751,11 @@ manifest_dump(const char *manifest_path, FILE *stream)
 		fprintf(stream, "    Ctime: %lld\n", (long long)mf->file_infos[i].ctime);
 	}
 	fprintf(stream, "Results (%u):\n", (unsigned)mf->n_objects);
-	for (i = 0; i < mf->n_objects; ++i) {
+	for (unsigned i = 0; i < mf->n_objects; ++i) {
 		char *hash;
 		fprintf(stream, "  %u:\n", i);
 		fprintf(stream, "    File info indexes:");
-		for (j = 0; j < mf->objects[i].n_file_info_indexes; ++j) {
+		for (unsigned j = 0; j < mf->objects[i].n_file_info_indexes; ++j) {
 			fprintf(stream, " %u", mf->objects[i].file_info_indexes[j]);
 		}
 		fprintf(stream, "\n");
